@@ -20,7 +20,7 @@ import shutil
 import sys
 from BeautifulSoup import BeautifulStoneSoup
 
-version = "0.7.5"
+version = "0.7.6"
 feed_template_default = """
 <html>
     <head>
@@ -1325,9 +1325,10 @@ class Program(hildon.Program):
         self.__abort_lock.release()
         if abort:
             sys.exit()
-        gobject.idle_add(self.update_status, self.__progress_info[0], item[0], item[1],
-            self.__progress_info[1], self.__progress_info[2], item[2],
-            self.__progress_info[3], self.__progress_info[4])
+        if item[0]:
+            gobject.idle_add(self.update_status, self.__progress_info[0], item[0], item[1],
+                self.__progress_info[1], self.__progress_info[2], item[2],
+                self.__progress_info[3], self.__progress_info[4])
 
 
     def update_feeds(self, feed_configs):
@@ -1351,10 +1352,11 @@ class Program(hildon.Program):
                 j = 0
                 try:
                     for url in urls:
+                        feed = None
+                        self.__progress_info = (feed_config, i, feed_count, j, url_count)
+                        del_before = None
+                        clear_cache = True
                         try:
-                            self.__progress_info = (feed_config, i, feed_count, j, url_count)
-                            del_before = None
-                            clear_cache = True
                             if feed_config.days_to_keep:
                                 del_before = date.today() - timedelta(feed_config.days_to_keep)
                                 clear_cache = False
@@ -1374,10 +1376,13 @@ class Program(hildon.Program):
                                 new_window = self.__model.use_new_window,
                                 feed_item_template = item_t, feed_update_template = update_t,
                                 page_template = page_t, feed_template = feed_t)
-                            new_item_count += feed.update()
+                            feed.update()
                             j += 1
                         except Exception:
                             pass
+                        finally:
+                            if feed:
+                                new_item_count += feed.new_item_count
                 finally:
                     gobject.idle_add(self.update_feed_complete, feed_config, new_item_count)
         except BaseException:
@@ -1483,13 +1488,16 @@ class Program(hildon.Program):
                         cache_path = ".cache", filename = feed_config.get_filename())
                     delete_thread = BannerThread(self.__window, _("clearing cache"))
                     delete_thread.execute(feed.delete)
-                    self.__model.refresh(feed_config.id)
+                    self.__model.update(feed_config.id)
                     if not only_cache:
                         if feed_config.icon_filename:
                             icon_filepath = os.path.join(self.__model.cache_path, feed_config.icon_filename)
                             if os.path.exists(icon_filepath):
                                 os.remove(icon_filepath)
                         self.__model.delete(feed_config.id)
+                # dirty hack to remove trash accumulated from previous versions
+                if len(selected) == len(self.__model.list):
+                    shutil.rmtree(os.path.join(self.__model.cache_path, ".cache"), True)
 
 
     def move_cache(self, from_path, to_path):
@@ -1513,41 +1521,42 @@ class Program(hildon.Program):
         if not filename:
             filename = os.path.expanduser("~/.osso_rss_feed_reader/feedlist.opml")
             fav_dir = os.path.expanduser("~/.osso_rss_feed_reader/cache/favicons")
-        f = open(filename, "r")
-        try:
-            opml = BeautifulStoneSoup(f)
-            outlines = filter(
-                lambda o: o.has_key("title") and o.has_key("xmlurl"),
-                opml.findAll("outline"))
-            for outline in outlines:
-                icon_file_name = ""
-                if fav_dir:
-                    if outline.has_key("id"):
-                        icon_file = outline["id"] + ".png"
-                        icon_file_src = os.path.join(fav_dir, icon_file)
-                        if os.path.exists(icon_file_src):
-                            icon_file_name = uuid.uuid1().hex + icon_file
-                            shutil.copy(icon_file_src,
-                                os.path.join(self.__model.cache_path, icon_file_name))
-                else:
-                    try:
-                        discovery_thread = BannerThread(self.__window, _("Importing feeds"))
-                        (url, title, icon_file_name, icon_data) = \
-                            discovery_thread.execute(feedcircuit.get_feed_details, outline["xmlurl"])
-                        if icon_file_name:
-                            icon_file_name = uuid.uuid1().hex + icon_file_name
-                            save_icon(os.path.join(self.__model.cache_path, icon_file_name), icon_data)
-                    except Exception, ex:
-                        msg_dlg = gtk.MessageDialog(parent = self.__window, flags = gtk.DIALOG_MODAL,
-                            type=gtk.MESSAGE_WARNING, buttons = gtk.BUTTONS_OK, 
-                            message_format = _("Cannot discover feed at given url") + "\n" + str(ex))
-                        msg_dlg.run()
-                        msg_dlg.destroy()
-                feed_config = FeedConfig(self.__model.cache_path, outline["xmlurl"], outline["title"],
-                    FeedConfig.mode_ommit, icon_file_name)
-                self.__model.append(feed_config)
-        finally:
-            f.close()
+        if os.path.exists(filename):
+            f = open(filename, "r")
+            try:
+                opml = BeautifulStoneSoup(f)
+                outlines = filter(
+                    lambda o: o.has_key("title") and o.has_key("xmlurl"),
+                    opml.findAll("outline"))
+                for outline in outlines:
+                    icon_file_name = ""
+                    if fav_dir:
+                        if outline.has_key("id"):
+                            icon_file = outline["id"] + ".png"
+                            icon_file_src = os.path.join(fav_dir, icon_file)
+                            if os.path.exists(icon_file_src):
+                                icon_file_name = uuid.uuid1().hex + icon_file
+                                shutil.copy(icon_file_src,
+                                    os.path.join(self.__model.cache_path, icon_file_name))
+                    else:
+                        try:
+                            discovery_thread = BannerThread(self.__window, _("Importing feeds"))
+                            (url, title, icon_file_name, icon_data) = \
+                                discovery_thread.execute(feedcircuit.get_feed_details, outline["xmlurl"])
+                            if icon_file_name:
+                                icon_file_name = uuid.uuid1().hex + icon_file_name
+                                save_icon(os.path.join(self.__model.cache_path, icon_file_name), icon_data)
+                        except Exception, ex:
+                            msg_dlg = gtk.MessageDialog(parent = self.__window, flags = gtk.DIALOG_MODAL,
+                                type=gtk.MESSAGE_WARNING, buttons = gtk.BUTTONS_OK, 
+                                message_format = _("Cannot discover feed at given url") + "\n" + str(ex))
+                            msg_dlg.run()
+                            msg_dlg.destroy()
+                    feed_config = FeedConfig(self.__model.cache_path, outline["xmlurl"], outline["title"],
+                        FeedConfig.mode_ommit, icon_file_name)
+                    self.__model.append(feed_config)
+            finally:
+                f.close()
 
 
     def import_feeds(self, source):
